@@ -1,11 +1,11 @@
 /* -*-c-*- ------------------ mix_vm.c :
  * Implementation of the functions declared in mix_vm.h
  * ------------------------------------------------------------------
- * Copyright (C) 2000, 2001, 2004 Free Software Foundation, Inc.
+ * Copyright (C) 2000, 2001, 2004, 2007, 2014 Free Software Foundation, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -528,8 +528,8 @@ mix_vm_get_error_string (mix_vm_error_t code)
     N_("Unknow error code")
   };
 
-  return errors[(code < 0 || code > MIX_VM_ERROR_UNEXPECTED)
-                ? MIX_VM_ERROR_UNEXPECTED + 1 : code];
+  return errors[code > MIX_VM_ERROR_UNEXPECTED ?
+                MIX_VM_ERROR_UNEXPECTED + 1 : code];
 }
 
 /* Breakpoints */
